@@ -161,7 +161,7 @@ impl Slack {
         let state = uuid::Uuid::new_v4();
         format!(
             "https://slack.com/oauth/v2/authorize?scope={}&client_id={}&user_scope={}&redirect_uri={}&state={}",
-            "commands,incoming-webhook,team:read,users:read,users:read.email,users.profile:read",
+            "commands,incoming-webhook,team:read,users:read,users:read.email,users.profile:read,channels:read,chat:write,channels:join",
             self.client_id,
             "identity.basic,identity.email",
             self.redirect_uri,
